using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using Infragistics.Win;
using Infragistics.Win.UltraWinSchedule;


namespace AppointmentDialog2007_CS
{
	#region ExtendedAppointmentInfo class
	/// <summary>
	/// Class which holds additional information for an <see cref="Infragistics.Win.UltraWinSchedule.Appointment"/> object.
	/// </summary>
	[Serializable()]
	public class ExtendedAppointmentInfo
	{
		private Appointment appointment = null;
		private AppointmentCategory category = null;
		private string startTimeZoneName = string.Empty;
		private string endTimeZoneName = string.Empty;

		/// <summary>
		/// Creates a new instance of the <see cref="ExtendedAppointmentInfo"/> class.
		/// </summary>
		public ExtendedAppointmentInfo()
		{
		}

		/// <summary>
		/// Creates a new instance of the <see cref="ExtendedAppointmentInfo"/> class.
		/// </summary>
		public ExtendedAppointmentInfo( Appointment appointment )
		{
			this.appointment = appointment;
		}

		/// <summary>
		/// Returns the <see cref="Infragistics.Win.UltraWinSchedule.Appointment"/> associated with this instance.
		/// </summary>
		public Appointment Appointment
		{
			get{ return this.appointment; }
		}

		/// <summary>
		/// Gets/sets the <see cref="AppointmentCategory"/> associated with the <see cref="Appointment"/>.
		/// </summary>
		public AppointmentCategory Category
		{
			get{ return this.category; }
			set
			{ 
				this.category = value;
				
				if ( this.appointment != null && this.category != null )
					this.appointment.Appearance = this.category.Appearance;
				else
				if ( this.appointment != null  && this.appointment.HasAppearance )
					this.appointment.ResetAppearance();
			}
		}

		/// <summary>
		/// Gets/sets the StandardName of the TimeZone which is specified
		/// for the Appointment's StartDateTime property.
		/// </summary>
		public string StartTimeZoneName
		{
			get{ return this.startTimeZoneName; }
			set{ this.startTimeZoneName = value; }
		}

		/// <summary>
		/// Gets/sets the StandardName of the TimeZone which is specified
		/// for the Appointment's EndDateTime property.
		/// </summary>
		public string EndTimeZoneName
		{
			get{ return this.endTimeZoneName; }
			set{ this.endTimeZoneName = value; }
		}

		/// <summary>
		/// Initializes this instance with the property values of the specified source instance.
		/// Note that the appointment reference is not copied.
		/// </summary>
		public void InitializeFrom( ExtendedAppointmentInfo source )
		{
			if ( source != null )
			{
				this.category = source.category;
				this.startTimeZoneName = source.startTimeZoneName;
				this.endTimeZoneName = source.endTimeZoneName;

				if ( this.appointment != null && this.category != null )
					this.appointment.Appearance = this.category.Appearance;
			}
		}
	}
	#endregion ExtendedAppointmentInfo class

	#region AppointmentCategory class
	/// <summary>
	/// Class which encapsulates information related to an <see cref="Infragistics.Win.UltraWinSchedule.Appointment"/> category.
	/// </summary>
	[Serializable()]
	public class AppointmentCategory
	{
		private string name = string.Empty;
		private Infragistics.Win.Appearance appearance = new Infragistics.Win.Appearance();

		/// <summary>
		/// Returns an instance of the <see cref="AppointmentCategory"/> to represent the 'Holiday' category.
		/// </summary>
		static public AppointmentCategory CreateHolidayCategory()
		{
			AppointmentCategory category = new AppointmentCategory();
			category.name = "Holiday";

			//	Since the holiday colors are the same for all schemes, it
			//	doesn't matter which color is used for the base color here
			Outlook2007ColorScheme colorScheme = new Outlook2007ColorScheme( Color.Empty );
			
			category.appearance.BackColor = colorScheme.HolidayBackColor;
			category.appearance.BackColor2 = colorScheme.HolidayBackColor2;
			category.appearance.BorderColor = colorScheme.HolidayBorderColor;
			category.appearance.BackGradientStyle = GradientStyle.Vertical;

			return category;
		}

		/// <summary>
		/// Private parameterless constructor.
		/// </summary>
		private AppointmentCategory()
		{
		}

		/// <summary>
		/// Creates a new instance of the <see cref="AppointmentCategory"/> class.
		/// </summary>
		public AppointmentCategory( string name, Color baseColor )
		{
			this.name = name;
			Outlook2007ColorScheme colorScheme = new Outlook2007ColorScheme( baseColor );

			this.appearance.BackColor = colorScheme.AppointmentBackColor;
			this.appearance.BackColor2 = colorScheme.AppointmentBackColor2;
			this.appearance.BorderColor = colorScheme.AppointmentBorderColor;

			this.appearance.BackGradientStyle = GradientStyle.Vertical;
		}

		/// <summary>
		/// Returns the name of this <see cref="AppointmentCategory"/>.
		/// </summary>
		public string Name
		{
			get{ return this.name; }
		}

		/// <summary>
		/// Returns the Appearance associated with this <see cref="AppointmentCategory"/>.
		/// </summary>
		public Infragistics.Win.Appearance Appearance
		{
			get{ return this.appearance; }
		}

		/// <summary>
		/// Returns the string representation of this instance.
		/// </summary>
		public override string ToString()
		{
			return this.Name;
		}

	}
	#endregion AppointmentCategory class
}
